@@ -2,7 +2,17 @@
 #   list.py                                                                   #
 #                                                                             #
 #   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
-#   All rights reserved.                                                      #
+#                                                                             #
+#   Licensed under the Apache License, Version 2.0 (the "License");           #
+#   you may not use this file except in compliance with the License.          #
+#   You may obtain a copy of the License at:                                  #
+#       http://www.apache.org/licenses/LICENSE-2.0                            #
+#                                                                             #
+#   Unless required by applicable law or agreed to in writing, software       #
+#   distributed under the License is distributed on an "AS IS" BASIS,         #
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  #
+#   See the License for the specific language governing permissions and       #
+#   limitations under the License.                                            #
 # --------------------------------------------------------------------------- #
 
 
@@ -29,12 +39,12 @@ from .exceptions import KeyExistsError
 
 def _raise_on_error(func: F) -> Callable[[F], F]:
     @functools.wraps(func)
-    def wrap(*args: Any, **kwargs: Any) -> Any:
+    def wrapper(*args: Any, **kwargs: Any) -> Any:
         try:
             return func(*args, **kwargs)
         except ResponseError as error:
             raise IndexError('list assignment index out of range') from error
-    return wrap
+    return wrapper
 
 
 class RedisList(Base, collections.abc.MutableSequence):
@@ -199,7 +209,7 @@ class RedisList(Base, collections.abc.MutableSequence):
                 if len(self) != len(other):
                     # self and other are different lengths.
                     return False
-                elif isinstance(other, collections.abc.Sequence):
+                elif isinstance(other, collections.abc.MutableSequence):
                     # self and other are the same length, and other is an
                     # ordered collection too.  Compare self's and other's
                     # elements, pair by pair.
