@@ -1,8 +1,18 @@
 # --------------------------------------------------------------------------- #
 #   monkey.py                                                                 #
 #                                                                             #
-#   Copyright © 2015-2021, original authors.                                  #
-#   All rights reserved.                                                      #
+#   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
+#                                                                             #
+#   Licensed under the Apache License, Version 2.0 (the "License");           #
+#   you may not use this file except in compliance with the License.          #
+#   You may obtain a copy of the License at:                                  #
+#       http://www.apache.org/licenses/LICENSE-2.0                            #
+#                                                                             #
+#   Unless required by applicable law or agreed to in writing, software       #
+#   distributed under the License is distributed on an "AS IS" BASIS,         #
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  #
+#   See the License for the specific language governing permissions and       #
+#   limitations under the License.                                            #
 # --------------------------------------------------------------------------- #
 'Monkey patches.'
 
@@ -36,8 +46,8 @@ def __eq__(self: ConnectionPool, other: Any) -> bool:
 ConnectionPool.__eq__ = __eq__  # type: ignore
 
 _logger.info(
-    'Monkey patched ConnectionPool.__eq__() to compare clients by connection '
-    'params'
+    'Monkey patched ConnectionPool.__eq__() to compare Redis clients by '
+    'connection params'
 )
 
 
@@ -60,6 +70,6 @@ json.JSONEncoder.default = _default  # type: ignore
 
 _logger.info(
     'Monkey patched json.JSONEncoder.default() to be able to JSONify any '
-    'instance of any class that defines a to_dict(), to_list(), or to_str() '
+    'instance of any class that defines a .to_dict(), .to_list(), or .to_str() '
     'method'
 )
